@@ -1,5 +1,5 @@
 /* Generate coff file
-   Copyright (C) 2002, 2003, 2004
+   Copyright (C) 2002, 2003, 2004, 2005
    Craig Franklin
 
 This file is part of gputils.
@@ -27,13 +27,15 @@ Boston, MA 02111-1307, USA.  */
 void coff_init(void);
 void coff_close_file(void);
 void coff_new_section(char *name, int addr, int flags);
-void coff_add_sym(char *name, int value, enum gpasmValTypes type);
+gp_symbol_type *coff_add_sym(char *name, int value, enum gpasmValTypes type);
 void coff_reloc(int symbol, short offset, unsigned short type);
 void coff_linenum(int emitted);
 gp_symbol_type *coff_add_filesym(char *name, int isinclude);
 void coff_add_eofsym(void);
 void coff_add_listsym(void);
 void coff_add_nolistsym(void);
+void coff_add_directsym(unsigned char command, char *string);
+void coff_add_identsym(char *string);
 char *coff_local_name(char *name);
 
 #endif
