@@ -1,5 +1,5 @@
 /* ".COD" file output for gplink
-   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004
+   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005
    James Bowman, Scott Dattalo
 
 This file is part of gputils.
@@ -49,9 +49,15 @@ init_DirBlock(DirBlockInfo *a_dir)
 
   /* Initialize the directory block with known data. It'll be written
    * to the .cod file after everything else */
-
+  gp_cod_strncpy(&a_dir->dir.block[COD_DIR_SOURCE], 
+	         state.codfilename,
+	         COD_DIR_DATE - COD_DIR_SOURCE);
+  gp_cod_date(&a_dir->dir.block[COD_DIR_DATE], 
+              COD_DIR_TIME - COD_DIR_DATE);
+  gp_cod_time(&a_dir->dir.block[COD_DIR_TIME], 
+              COD_DIR_VERSION - COD_DIR_TIME);
   gp_cod_strncpy(&a_dir->dir.block[COD_DIR_VERSION], 
-	         GPLINK_VERSION_STRING,
+	         VERSION,
 	         COD_DIR_COMPILER - COD_DIR_VERSION);
   gp_cod_strncpy(&a_dir->dir.block[COD_DIR_COMPILER], 
 	         "gplink",
@@ -79,7 +85,7 @@ assign_file_id(void)
   int *value;
   
   /* build a case sensitive file table */
-  file_table = push_symbol_table(NULL, 0);
+  file_table = push_symbol_table(NULL, false);
   
   symbol = state.object->symbols;
   while(symbol != NULL) {
@@ -121,9 +127,9 @@ cod_init(void)
     strncat(state.codfilename, ".cod", sizeof(state.codfilename));
   }
 
-  if (state.codfile == suppress) {
+  if ((gp_num_errors) || (state.codfile == suppress)) {
     state.cod.f = NULL;
-    state.cod.enabled = 0;
+    state.cod.enabled = false;
     unlink(state.codfilename);
   } else {
     state.cod.f = fopen(state.codfilename, "wb");
@@ -131,7 +137,7 @@ cod_init(void)
       perror(state.codfilename);
       exit(1);
     }
-    state.cod.enabled = 1;
+    state.cod.enabled = true;
   }
 
   if(!state.cod.enabled)
@@ -279,7 +285,8 @@ cod_lst_line(int line_type)
     gp_putl16(&lb.block[offset + COD_LS_SLINE], state.lst.src->line_number);
 
     /* Write the address of the opcode. */
-    gp_putl16(&lb.block[offset + COD_LS_SLOC], state.lst.was_org);
+    gp_putl16(&lb.block[offset + COD_LS_SLOC],
+              state.lst.was_org << state.byte_addr);
 
     break;
   case COD_LAST_LST_LINE:
@@ -501,7 +508,7 @@ cod_write_code(void)
 	     is needed. This is done by writing the start and end address to
 	     the directory map. */
 	  gp_putl16(&rb.block[offset], 2*start_address);
-	  gp_putl16(&rb.block[offset+2], 2*(i-1));
+	  gp_putl16(&rb.block[offset+2], 2*(i-1) + 1);
 
 	  offset += 4;
 	  if(offset>=COD_BLOCK_SIZE) {
@@ -545,6 +552,79 @@ cod_write_code(void)
 
 }
 
+/* cod_write_debug - write debug symbols to the .cod file
+ */
+static void
+cod_write_debug(void)
+{
+  /* Each symbol is written as a dynamically sized structure to the 
+   * .cod file. Its format is like this:
+   * position  0               length of the symbol name
+   * positions 1 to len        the symbol name
+   * positions len+1 & len+2   Type of symbol (16 bits)
+   * positions len+3 to len+7  Value of symbol
+   */
+#define COD_DEBUG_ADDR  0   /* type info is first */
+#define COD_DEBUG_CMD   4   /* value info is 4 bytes after the address */
+#define COD_DEBUG_MSG   6   /* message is 6 bytes after the address */
+#define COD_DEBUG_EXTRA 6   /* symbol name length + 6 is total structure size */
+#define MAX_STRING_LEN  255 /* Maximum length of a debug message */
+  int offset;
+  int len;
+  gp_symbol_type *symbol;
+  gp_aux_type *aux;
+  Block db;
+  char command;
+  char *string;
+  
+  if(!state.cod.enabled)
+    return;
+
+  gp_cod_create(&db, &blocks);
+
+  offset = 0;
+
+  symbol = state.object->symbols;
+  
+  while (symbol) {
+    if (strcasecmp(".direct", symbol->name) == 0) {
+      assert(symbol->num_auxsym == 1);
+      aux = symbol->aux_list;
+      assert(aux != NULL);
+
+      command = aux->_aux_symbol._aux_direct.command;
+      string = aux->_aux_symbol._aux_direct.string;
+      
+      len = strlen(string);
+
+      /* If this message extends past the end of the cod block
+       * then write this block out */
+
+      if((offset + len + COD_DEBUG_EXTRA) >= COD_BLOCK_SIZE) {
+        write_cod_block(&main_dir, COD_DIR_MESSTAB, COD_DIR_MESSTAB+2, &db);
+        gp_cod_next(&db, &blocks);
+        offset = 0;
+      }
+
+      /* write 32 bits, big endian */
+      gp_putb32(&db.block[offset+COD_DEBUG_ADDR], symbol->value);
+      
+      db.block[offset + COD_DEBUG_CMD] = command;
+      gp_cod_strncpy(&db.block[offset + COD_DEBUG_MSG], string, MAX_STRING_LEN);
+
+
+      offset += (len + COD_DEBUG_EXTRA);
+    } 
+    symbol = symbol->next;  
+  }
+
+  if(offset)
+    write_cod_block(&main_dir, COD_DIR_MESSTAB, COD_DIR_MESSTAB+2, &db);
+
+  gp_cod_delete(&db);
+
+}
+
 static void
 write_directory(void)
 {
@@ -595,6 +675,8 @@ cod_close_file(void)
 
   cod_write_code();
 
+  cod_write_debug();
+
   gp_cod_strncpy(&main_dir.dir.block[COD_DIR_PROCESSOR], 
 	         gp_processor_name(state.processor, 2),
 	         COD_DIR_LSYMTAB - COD_DIR_PROCESSOR);
