@@ -22,7 +22,7 @@ Boston, MA 02111-1307, USA.  */
 #ifndef GPLINK_H
 #define GPLINK_H
 
-#define GPLINK_VERSION_STRING ("gplink-" VERSION " alpha")
+#define GPLINK_VERSION_STRING ("gplink-" VERSION " beta")
 
 #define MAX_PATHS 100
 
@@ -40,7 +40,7 @@ extern struct gplink_state {
   char *paths[MAX_PATHS];          /* the list of include paths */
   int numpaths;                    /* number of paths in the list */
   int byte_addr;                   /* program memory uses byte addressing */
-  enum pic_processor processor;
+  pic_processor_t processor;
   enum proc_class class;
   struct {
     int level;
