@@ -1,5 +1,5 @@
 /* .cod file support
-   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004
+   Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005
    James Bowman, Scott Dattalo
 
 This file is part of gputils.
@@ -203,5 +203,7 @@ void gp_cod_clear(Block *b);
 void gp_cod_delete(Block *b);
 void gp_cod_next(Block *b, int *block_number);
 void gp_cod_create(Block *b, int *block_number);
+void gp_cod_date(char *buffer, size_t sizeof_buffer);
+void gp_cod_time(char *buffer, size_t sizeof_buffer);
 
 #endif
