@@ -524,7 +524,7 @@ typedef struct gp_symbol_type
   unsigned long type;
 
   /* storage class */
-  char class;
+  signed char class;
 
    /* number of auxiliary symbols */
   char num_auxsym;
@@ -623,7 +623,7 @@ typedef struct gp_object_type
   int isnew;
 
   /* processor */
-  enum pic_processor processor;
+  pic_processor_t processor;
   
   /* processor class */
   enum proc_class class;
